@@ -1,26 +1,28 @@
 from dataclasses import dataclass
 import logging
-from typing import Callable, List, Union
+from typing import Callable, List, Optional, Type, Union, cast
 
 from cornflakes.decorator._add_dataclass_slots import add_slots
 from cornflakes.decorator.config._config_group import config_group
 from cornflakes.decorator.config._dict import create_dict_file_loader, to_dict
 from cornflakes.decorator.config._ini import create_ini_file_loader, to_ini, to_ini_bytes
 from cornflakes.decorator.config._loader import Loader
-from cornflakes.decorator.config._protocols import Config
+from cornflakes.decorator.config._protocols import Config, ConfigGroup
 from cornflakes.decorator.config._yaml import create_yaml_file_loader, to_yaml, to_yaml_bytes
 
 
 def config(  # noqa: C901
-        config_cls=None,
-        files: Union[str, List[str]] = None,
-        sections: Union[str, List[str]] = None,
-        use_regex: bool = False,
-        is_list: Union[bool, int] = False,
-        default_loader: Loader = Loader.INI_LOADER,
-        *args,
-        **kwargs,
-) -> Callable[..., Config]:
+    config_cls=None,
+    files: Optional[Union[List[str], str]] = None,
+    sections: Optional[Union[List[str], str]] = None,
+    use_regex: Optional[bool] = False,
+    is_list: Optional[Union[bool, int]] = False,
+    default_loader: Loader = Loader.INI_LOADER,
+    allow_empty: Optional[bool] = False,
+    filter_function: Optional[Callable[..., bool]] = None,
+    *args,
+    **kwargs,
+) -> Union[Union[Config, ConfigGroup], Callable[..., Union[Config, ConfigGroup]]]:
     """Config decorator to parse Ini Files and implements config loader methods to config-classes.
 
     :param config_cls: Config class
@@ -31,11 +33,13 @@ def config(  # noqa: C901
     :param default_loader: Default config parser method (enum)
     :param args: Default configs to overwrite dataclass args
     :param kwargs: Default configs to overwrite dataclass args
+    :param allow_empty: Flag that allows empty config result
+    :param filter_function: Optional filter method for config
 
     :returns: wrapped class or the wrapper itself with the custom default arguments if the config class is not
     """
 
-    def wrapper(cls) -> Config:
+    def wrapper(cls) -> Union[Config, ConfigGroup]:
         """Wrapper function for the config decorator config_decorator."""
         # Check __annotations__
         if not hasattr(cls, "__annotations__"):
@@ -53,13 +57,15 @@ def config(  # noqa: C901
                 config_cls=cls,
                 files=files,
                 **kwargs,
-            )
+            )(cls)
 
         cls = add_slots(dataclass(cls, *args, **kwargs))
-        cls.__config_sections__ = sections if isinstance(sections, list) else [sections]
-        cls.__config_files__ = files if isinstance(files, list) else [files]
+        cls.__config_sections__ = sections if isinstance(sections, list) else [sections] if sections else []
+        cls.__config_files__ = files if isinstance(files, list) else [files] if files else []
         cls.__multi_config__ = use_regex
         cls.__config_list__ = is_list
+        cls.__allow_empty_config__ = allow_empty
+        cls.__config_filter_function__ = filter_function
 
         def new(self, *new_args, **new_kwargs):
             # two chars missing in original of next line ...
@@ -77,7 +83,7 @@ def config(  # noqa: C901
         cls.from_dict = staticmethod(create_dict_file_loader(cls=cls))
         cls.from_file = getattr(cls, str(default_loader.value), cls.from_ini)
 
-        return cls
+        return cast(Type[Config], cls)
 
     if config_cls:
         return wrapper(config_cls)
