@@ -1,5 +1,5 @@
 from dataclasses import dataclass
-from typing import Callable, List, Union
+from typing import Callable, List, Optional, Union, cast
 
 from cornflakes.decorator._add_dataclass_slots import add_slots
 from cornflakes.decorator.config._dict import create_dict_group_loader, to_dict
@@ -10,12 +10,14 @@ from cornflakes.decorator.config._yaml import create_yaml_group_loader, to_yaml,
 
 
 def config_group(  # noqa: C901
-        config_cls=None,
-        files: Union[str, List[str]] = None,
-        default_loader: Loader = Loader.INI_LOADER,
-        *args,
-        **kwargs,
-) -> Callable[..., ConfigGroup]:
+    config_cls=None,
+    files: Optional[Union[str, List[str]]] = None,
+    default_loader: Loader = Loader.INI_LOADER,
+    allow_empty: Optional[bool] = False,
+    filter_function: Optional[Callable[..., bool]] = None,
+    *args,
+    **kwargs,
+) -> Union[ConfigGroup, Callable[..., ConfigGroup]]:
     """Config decorator with a Subset of configs to parse Ini Files.
 
     :param config_cls: Config class
@@ -23,6 +25,8 @@ def config_group(  # noqa: C901
     :param default_loader: Default config parser method (enum)
     :param args: Default configs to overwrite dataclass args
     :param kwargs: Default configs to overwrite dataclass args
+    :param allow_empty: Flag that allows empty config result
+    :param filter_function: Optional filter method for config
 
     :returns: wrapped class or the wrapper itself with the custom default arguments if the config class is not
 
@@ -31,7 +35,9 @@ def config_group(  # noqa: C901
     def wrapper(cls) -> ConfigGroup:
 
         cls = add_slots(dataclass(cls, *args, **kwargs))
-        cls.__config_files__ = files if isinstance(files, list) else [files]
+        cls.__config_files__ = files if isinstance(files, list) else [files] if files else []
+        cls.__allow_empty_config__ = allow_empty
+        cls.__config_filter_function__ = filter_function
 
         # Check __annotations__
         if not hasattr(cls, "__annotations__"):
@@ -53,7 +59,7 @@ def config_group(  # noqa: C901
         cls.from_dict = staticmethod(create_dict_group_loader(cls=cls))
         cls.from_file = getattr(cls, str(default_loader.value), cls.from_ini)
 
-        return cls
+        return cast(ConfigGroup, cls)
 
     if config_cls:
         return wrapper(config_cls)
