@@ -1,15 +1,15 @@
-import logging
 from collections import OrderedDict
-from typing import Any, Callable, Dict, List, Union
+import logging
+from typing import Any, Callable, Dict, List, Optional, Union
 
 from cornflakes import ini_load
 from cornflakes.decorator.config._helper import is_config, is_config_list
-from cornflakes.decorator.config._protocols import ConfigGroup, ConfigGroupLoader
+from cornflakes.decorator.config._protocols import Config, ConfigGroup
 
 
 def create_group_loader(
-        cls=None,
-        loader: ConfigGroupLoader = ini_load,
+    cls: ConfigGroup,
+    loader=ini_load,
 ) -> Callable[..., ConfigGroup]:
     """Config decorator to parse Ini Files and implements from_file method to config-group-classes.
 
@@ -20,10 +20,11 @@ def create_group_loader(
     """
 
     def from_file(
-            files: Union[str, List[str], Dict[str, Union[str, List[str]]]] = None,
-            config_dict: Dict[str, Any] = None,
-            *slot_args,
-            **slot_kwargs,
+        files: Optional[Union[Dict[str, Union[List[str], str]], List[str], str]] = None,
+        config_dict: Optional[Dict[str, Any]] = None,
+        filter_function: Optional[Callable[[Config], bool]] = None,
+        *slot_args,
+        **slot_kwargs,
     ) -> ConfigGroup:
         """Config parser from config files.
 
@@ -31,6 +32,7 @@ def create_group_loader(
         :param config_dict: Config dictionary to pass already loaded configs
         :param slot_args: Default configs to overwrite passed class
         :param slot_kwargs: Default configs to overwrite passed class
+        :param filter_function: Optional filter method for config
 
         :returns: Nested Lists of Config Classes
 
@@ -41,12 +43,14 @@ def create_group_loader(
         if not config_dict:
             config_dict = OrderedDict(loader({None: files}))
         logging.debug(f"Read config with sections: {config_dict.keys()}")
-        for slot_name, slot_class in list(cls.__annotations__.items())[len(slot_args):]:
+        for slot_name, slot_class in list(getattr(cls, "__annotations__", {}).items())[len(slot_args) :]:
             if is_config_list(slot_class):
                 slot_class = slot_class.__args__[0]
             if is_config(slot_class):
-                slot_kwargs.update(slot_class.from_dict(config_dict=config_dict, sections=slot_name))
-        error_args = [key for key in slot_kwargs if key not in cls.__slots__]
+                slot_kwargs.update(
+                    slot_class.from_dict(config_dict=config_dict, sections=slot_name, filter_function=filter_function)
+                )
+        error_args = [key for key in slot_kwargs if key not in getattr(cls, "__slots__", ())]
         if error_args:
             logging.warning(f"The variables {error_args} in **{cls.__name__}** are not defined!")
             logging.warning("Use generate_group in build script to auto generate the config group!")
